summaryrefslogtreecommitdiffstats
path: root/kexi/3rdparty/kolibs/koGlobal.h
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/3rdparty/kolibs/koGlobal.h')
-rw-r--r--kexi/3rdparty/kolibs/koGlobal.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kexi/3rdparty/kolibs/koGlobal.h b/kexi/3rdparty/kolibs/koGlobal.h
index cad645b4..15523b3e 100644
--- a/kexi/3rdparty/kolibs/koGlobal.h
+++ b/kexi/3rdparty/kolibs/koGlobal.h
@@ -25,7 +25,7 @@
#include <tqstringlist.h>
#include <tqfont.h>
#include <tqmap.h>
-class KConfig;
+class TDEConfig;
#include <koffice_export.h>
class KOFFICECORE_EXPORT KoGlobal
@@ -46,12 +46,12 @@ public:
}
/**
* @return the global KConfig object around kofficerc.
* kofficerc is used for KOffice-wide settings, from totally unrelated classes,
* so this is the centralization of the KConfig object so that the file is
* parsed only once
*/
- static KConfig* kofficeConfig() {
+ static TDEConfig* kofficeConfig() {
return self()->_kofficeConfig();
}
@@ -87,13 +87,13 @@ private:
TQFont _defaultFont();
TQStringList _listOfLanguages();
TQStringList _listOfLanguageTags();
- KConfig* _kofficeConfig();
+ TDEConfig* _kofficeConfig();
void createListOfLanguages();
int m_pointSize;
typedef TQMap<TQString, TQString> LanguageMap;
LanguageMap m_langMap; // display-name -> language tag
- KConfig* m_kofficeConfig;
+ TDEConfig* m_kofficeConfig;
int m_dpiX;
int m_dpiY;
// No BC problem here, constructor is private, feel free to add members
@@ -46,12 +46,12 @@ public:
}
/**
- * @return the global KConfig object around kofficerc.
+ * @return the global TDEConfig object around kofficerc.
* kofficerc is used for KOffice-wide settings, from totally unrelated classes,
@@ -46,12 +46,12 @@ public:
* kofficerc is used for KOffice-wide settings, from totally unrelated classes,
- * so this is the centralization of the KConfig object so that the file is
+ * so this is the centralization of the TDEConfig object so that the file is
* parsed only once
*/